@@ -1,6 +1,5 @@
 import json, os
 from httpx import AsyncClient
-from urllib.parse import quote
 from nonebot import on_fullmatch, on_type, require, on_startswith
 from nonebot.adapters.onebot.v11 import PokeNotifyEvent, Bot, GroupMessageEvent, FriendRequestEvent, MessageEvent, PrivateMessageEvent, GroupRequestEvent, GroupIncreaseNoticeEvent
 require("nonebot_plugin_alconna")
@@ -45,9 +44,9 @@ async def a_handle():
     await a_word.finish(f"{hitokoto}    ----{who}[{source}]")
 
 @poke.handle()
-async def poke_handle(bot: Bot, event: GroupMessageEvent , t: PokeNotifyEvent):
+async def poke_handle(bot: Bot, event: GroupMessageEvent):
     if event.sub_type == "poke":
-        if str(event.get_user_id()) != event.self_id and t.target_id == event.self_id:
+        if str(event.get_user_id()) != event.self_id :
             t = Target(id = event.get_user_id(), private= True, scope = SupportScope.qq_client)
             async with AsyncClient() as client:
                 text = await client.get("https://act.jiawei.xin:10086/lib/api/maren.php")
@@ -72,7 +71,7 @@ async def f_handle(event: FriendRequestEvent):
             )
         
 @approve.handle()
-async def a_handle(bot: Bot, event: MessageEvent):
+async def app_handle(bot: Bot, event: MessageEvent):
     i = event.message.extract_plain_text()
     a = i[2:]
 
@@ -99,6 +98,7 @@ async def mf_handle(event: PrivateMessageEvent):
     msg = event.get_message()
     user_id = event.get_user_id()
     name = event.sender.nickname
+    
     if user_id != "2401128923":
         t = Target(id ="2401128923", private= True, scope = SupportScope.qq_client)
         log = event.get_log_string()
@@ -129,7 +129,9 @@ async def mi_handle(event: GroupMessageEvent, bot: Bot):
     else:
         user_id = event.get_message().extract_plain_text()
         user_id = user_id[3:]
-    re = await bot.call_api("get_stranger_info", user_id= user_id)
+
+    re = await bot.call_api("get_stranger_info", user_id= user_id) # type: ignore
+
     await msg_id.finish(str(re))
 
 @debug.handle()
@@ -137,14 +139,20 @@ async def debug_handle(event: MessageEvent):
         title = event.get_message().extract_plain_text()
         title = title[2:]
         async with AsyncClient() as cli:
-            url = await cli.get(f"https://api.xingzhige.com/API/Kugou_GN_new/?name={quote(title)}")
-            url= url.json()
+            p = {"name": title}
+            url = await cli.get(f"https://api.xingzhige.com/API/Kugou_GN_new/", params= p)
+            
+            if url.status_code == 200:
+                url= url.json()
 
-            ti = [i["songname"] for i in url["data"] if "songname" in i]
-            name = [i["name"] for i in url["data"] if "name" in i]
+                ti = [i["songname"] for i in url["data"] if "songname" in i]
+                name = [i["name"] for i in url["data"] if "name" in i]
 
-            output = "\n".join(f"{i+1}: {a_item} - {b_item}" for i,(a_item, b_item) in enumerate(zip(ti, name)))
-            await debug.send(f"{output}\n\nPS: 请在十五秒内输入序号")
+                output = "\n".join(f"{i+1}: {a_item} - {b_item}" for i,(a_item, b_item) in enumerate(zip(ti, name)))
+                await debug.send(f"{output}\n\nPS: 请在十五秒内输入序号")
+            
+            else:
+                await debug.finish("获取链接的时候404了", at_sender= True)
 
         @waiter(waits=["message"], keep_session=True)
         async def check(event: GroupMessageEvent):
@@ -158,17 +166,21 @@ async def debug_handle(event: MessageEvent):
             return
 
         async with AsyncClient() as cli:
-            url = await cli.get(f"https://api.xingzhige.com/API/Kugou_GN_new/?name={quote(title)}&n={resp}")
-            url= url.json()
+            p = {"name": title, "n": resp}
+            url = await cli.get(f"https://api.xingzhige.com/API/Kugou_GN_new/", params= p)
+            if url.status_code == 200:
+                url= url.json()
+                data = MusicShare(
+                    kind= MusicShareKind.QQMusic,
+                    title= url["data"]["songname"],
+                    content= url["data"]["name"],
+                    url= url["data"]["songurl"],
+                    audio= url["data"]["src"],
+                    thumbnail= url["data"]["cover"]
+                )
 
-            data = MusicShare(
-                kind= MusicShareKind.QQMusic,
-                title= url["data"]["songname"],
-                content= url["data"]["name"],
-                url= url["data"]["songurl"],
-                audio= url["data"]["src"],
-                thumbnail= url["data"]["cover"]
-            )
-
-            data = UniMessage(data)
-            await data.finish()
+                data = UniMessage(data)
+                await data.finish()
+            
+            else:
+                await debug.finish("获取不到歌曲信息")
\ No newline at end of file
